==> 2.5.0.zip: cloudlog/application/language/italian/awards_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['awards_info_button'] = "Award Info";
$lang['awards_show_worked'] = "Show worked";
$lang['awards_show_confirmed'] = "Show confirmed";
$lang['awards_show_not_worked'] = "Show not worked";
$lang['awards_show_cq_map'] = "Show CQ Zone Map";
$lang['awards_summary'] = "Summary";
$lang['awards_total'] = "Total";
$lang['awards_total_worked'] = "Total worked";
$lang['awards_total_confirmed'] = "Total confirmed";


$lang['awards_cq_page_title'] = "Awards - CQ Magazine WAZ";


/*
___________________________________________________________________________________________
CQ -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_cq_description_ln1'] = "CQ Magazine WAZ Award";
$lang['awards_cq_description_ln2'] = "The CQ Magazine is located in the US and one of the most popular amateur radio magazines in the world. The magazine first appeared in January 1945 and focuses on awards and the practical aspects of amateur radio.";
$lang['awards_cq_description_ln3'] = "The WAZ Award stands for 'Worked All Zones' and requires radio contacts to all 40 CQ Zones along with the corresponding confirmation.";
$lang['awards_cq_description_ln4'] = "You can find all the information and rules on the Website of the <a href='https://cq-amateur-radio.com/cq_awards/cq_waz_awards/index_cq_waz_award.html' target='_blank'>CQ Magazine</a>.";


/*
___________________________________________________________________________________________
DOK -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_dok_description_ln1'] = "DOK Award";
$lang['awards_dok_description_ln2'] = "Germany extends over 630 km from East to West and nearly 900 km from North to South. Around 70,000 of Germany's 82 million inhabitants are licensed hams, with more than 40,000 of them being members of DARC. DOK is a system that provides individual local chapters with an identifier and means 'Deutscher Ortsverband Kenner' (English: 'German Local Association Identifier').";
$lang['awards_dok_description_ln3'] = "The DOK consists of a letter for the district and a two-digit number for the local chapter, like P03 Friedrichshafen (city of the 'Hamradio exhibition') or F41 Baunatal (location of the DARC headquarters). Note: A zero in a DOK is a common mistake, often being logged as the letter O.";
$lang['awards_dok_description_ln4'] = "This information is provided by the <a href='https://www.darc.de/der-club/referate/conteste/wag-contest/en/service/districtsdoks/' target='_blank'>DARC website</a>. Information about the DOK Awards and its rules can be found <a href='https://www.darc.de/der-club/referate/conteste/wag-contest/en/service/award-check/' target='_blank'>here</a>.";


/*
___________________________________________________________________________________________
DXCC -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_dxcc_description_ln1'] = "DXCC Award";
$lang['awards_dxcc_description_ln2'] = "DXCC stands for 'DX Century Club,' an award based on worked countries. The DXCC List is based on an article created in 1935 by Clinton B. DeSoto, W1CBD, titled <a href='http://www.arrl.org/desoto' target='_blank'>'How to Count Countries Worked, A New DX Scoring System'</a>.";
$lang['awards_dxcc_description_ln3'] = "You can find all information about the DXCC Award on the <a href='https://www.arrl.org/dxcc-rules' target='_blank'>ARRL website</a>.";
$lang['awards_dxcc_description_ln4'] = "Important Note: Over time, the criteria for the DXCC List have changed. The List remains unchanged until an entity no longer satisfies the criteria under which it was added, at which time it is moved to the Deleted List. You will find Deleted DXCC entities also in the lists on Cloudlog. Be aware that these DXCC entities are outdated and no longer valid.";


/*
___________________________________________________________________________________________
FFMA -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_ffma_description_ln1'] = "Fred Fish Memorial Award";
$lang['awards_ffma_description_ln2'] = "The Fred Fish Memorial Award was created in honor of Fred Fish, W5FF (SK), who was the first amateur to have worked and confirmed all 488 Maidenhead grid squares in the 48 contiguous United States on 6 Meters.";
$lang['awards_ffma_description_ln3'] = "The award will be given to any amateur who can duplicate W5FF's accomplishment.";
$lang['awards_ffma_description_ln4'] = "For more information, you can visit this link: <a href='https://www.arrl.org/ffma' target='_blank'>https://www.arrl.org/ffma</a>.";


/*
___________________________________________________________________________________________
IOTA -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_iota_description_ln1'] = "IOTA Awards";
$lang['awards_iota_description_ln2'] = "IOTA is an exciting and innovative activity program that has captured the interest of thousands of radio amateurs worldwide. Established in 1964, it promotes radio contacts with stations located on islands around the world to enhance the experience of all those active on the amateur bands. To achieve this, it draws on the widespread mystique surrounding islands.";
$lang['awards_iota_description_ln3'] = "It is administered by Islands On The Air (IOTA) Ltd (referred to as IOTA Management) in partnership with the Radio Society of Great Britain (RSGB). IOTA Management has grouped the world's islands into approximately 1200 'IOTA groups,' each having varying numbers of 'counters,' which are qualifying islands. These listings are published in the IOTA Directory and on the IOTA website. The objective for the IOTA Island Chaser is to make radio contact with at least one counter in as many of these groups as possible. The program has a well-defined set of rules and encourages friendly competition among chasers by publishing participant performance in an Honor Roll and annual listings, as well as recognizing it with certificates and prestigious awards.";
$lang['awards_iota_description_ln4'] = "You can also find this information on the <a href='https://www.iota-world.org/' target='_blank'>IOTA WORLD website</a>.";


/*
___________________________________________________________________________________________
POTA -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_pota_description_ln1'] = "POTA Awards";
$lang['awards_pota_description_ln2'] = "Parks on the Air® (POTA) started in early 2017 when the ARRL's National Parks on the Air special event ended. A group of volunteers wanted to continue the fun beyond the one-year event, and thus, POTA was born.";
$lang['awards_pota_description_ln3'] = "POTA works similarly to SOTA, with Activators and Hunters. For the awards, there are several categories based on the number of parks, geographic areas, and more.";
$lang['awards_pota_description_ln4'] = "For more information about the available awards and categories, please visit the <a href='https://parksontheair.com/pota-awards/' target='_blank'>Parks on the Air® website</a>.";


/*
___________________________________________________________________________________________
SIG -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_sig_description_ln1'] = "SIG Information";
$lang['awards_sig_description_ln2'] = "The SIG or Signature Category provides the possibility to use any kind of 'Award Signature' for awards that are not implemented in Cloudlog.";
$lang['awards_sig_description_ln3'] = "The reason for this is that the common ADIF format provides only a few dedicated fields for certain awards. SIG still makes it possible to use and evaluate all other types of signature markers.";
$lang['awards_sig_description_ln4'] = "In the QSO processing, you will find two fields: 'SIG' contains the actual marker, which is also visible in the award evaluation, and 'SIG INFO,' which contains a description of the signature. Both fields are freely customizable.";


/*
___________________________________________________________________________________________
SOTA -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_sota_description_ln1'] = "SOTA Awards";
$lang['awards_sota_description_ln2'] = "SOTA (Summits On The Air) is an award scheme for radio amateurs that encourages portable operation in mountainous areas.";
$lang['awards_sota_description_ln3'] = "It is fully operational in nearly a hundred countries worldwide. Each country has its own Association that defines the recognized SOTA summits within that Association. Each summit earns the activators and chasers a score related to the height of the summit. Certificates are available for various scores, leading to the prestigious 'Mountain Goat' and 'Shack Sloth' trophies. An Honor Roll for Activators and Chasers is maintained in the SOTA online database.";
$lang['awards_sota_description_ln4'] = "For more information, please visit: <a href='https://www.sota.org.uk/' target='_blank'>https://www.sota.org.uk/</a>.";


/*
___________________________________________________________________________________________
US Counties -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_counties_description_ln1'] = "US County Award";
$lang['awards_counties_description_ln2'] = "The United States of America Counties Award (USA-CA), sponsored by CQ magazine, is issued for confirmed two-way radio contacts with specified numbers of U.S. counties under rules and conditions you can find <a href='https://cq-amateur-radio.com/cq_awards/cq_usa_ca_awards/cq_usa_ca_awards.html' target='_blank'>here</a>.";
$lang['awards_counties_description_ln3'] = "USA-CA is available to all licensed amateurs worldwide and is issued to individuals for all county contacts made, regardless of callsigns used, operating locations, or dates.";
$lang['awards_counties_description_ln4'] = "Special USA-CA awards are also available to SWLs on a heard basis.";


/*
___________________________________________________________________________________________
US Gridmaster -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_us_gridmaster_description_ln1'] = "US Gridmaster Award";
$lang['awards_us_gridmaster_description_ln2'] = "The GridMaster Award is the most prestigious AMSAT award, first introduced in 2014 by the Star Comm Group. It is available to all amateur radio operators worldwide who manage to work all 488 grid squares in the USA via satellite and can provide QSL confirmations for each contact.";
$lang['awards_us_gridmaster_description_ln3'] = "Official information from the <a href='https://www.amsat.org/gridmaster/' target='_blank'>website</a>: Two-way communication must be established via amateur satellite with each grid. There is no minimum signal report required. Contacts must be made from the same location or from locations no two of which are more than 200 kilometers apart. The applicant's attestation in the award application serves as affirmation of abidance by the distance rule. Individuals may apply for and be granted multiple GridMaster awards when achieved from another location, which is in a different 200-kilometer circle.";
$lang['awards_us_gridmaster_description_ln4'] = "This map shows only QSOs worked on SAT.";


/*
___________________________________________________________________________________________
JA Gridmaster -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_ja_gridmaster_description_ln1'] = "JA Gridmaster Award";
$lang['awards_ja_gridmaster_description_ln2'] = "Just as the US Gridmaster this Award is based on working all gridsquares of Japan.";
$lang['awards_ja_gridmaster_description_ln3'] = "Additional Information and the rules about this award are still pending.";
$lang['awards_ja_gridmaster_description_ln4'] = "";


/*
___________________________________________________________________________________________
VUCC -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_vucc_description_ln1'] = "VUCC - VHF/UHF Century Club Award";
$lang['awards_vucc_description_ln2'] = "The VHF/UHF Century Club Award is given for a minimum number of worked and confirmed gridsquares on a desired band.";
$lang['awards_vucc_description_ln3'] = "Official information and the rules can be found in this document: <a href='https://www.amsat.org/gridmaster/' target='_blank'>Click here</a>.";
$lang['awards_vucc_description_ln4'] = "Only VHF/UHF bands are relevant.";


/*
___________________________________________________________________________________________
WAS -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_was_description_ln1'] = "WAS Award";
$lang['awards_was_description_ln2'] = "ARRL's most popular award is the Worked All States Award. Thousands upon thousands of awards have been issued to hams around the world. In ARRL's 101st year, they have redesigned the certificates and the program in hopes of streamlining and improving the award program.";
$lang['awards_was_description_ln3'] = "The WAS (Worked All States) Award is available to all amateurs worldwide who submit proof with written confirmation of contacts with each of the 50 states of the United States of America. Amateurs in the U.S. and its possessions must be members of ARRL to apply for a WAS. Applicants from outside the U.S. are exempt from this requirement.";
$lang['awards_was_description_ln4'] = "All information and rules for the ARRL WAS Award can be found <a href='https://www.arrl.org/was' target='_blank'>here</a>.";


/*
___________________________________________________________________________________________
WWFF -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_wwff_description_ln1'] = "WWFF - World Wide Flora and Fauna Award";
$lang['awards_wwff_description_ln2'] = "WWFF, World Wide Flora and Fauna in Amateur Radio, encourages licensed ham radio operators to leave their shacks and operate portable in Protected Flora & Fauna areas (PFF) worldwide.";
$lang['awards_wwff_description_ln3'] = "More than 26,000 Protected Flora & Fauna (PFF) areas worldwide are already registered in the WWFF Directory. Hunters and Activators can apply for colorful awards, both globally and nationally.";
$lang['awards_wwff_description_ln4'] = "For more information, please visit: <a href='https://wwff.co/awards/' target='_blank'>https://wwff.co/awards/</a>.";

==> 2.6.10.zip: cloudlog/application/language/italian/awards_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['awards_info_button'] = "Award Info";
$lang['awards_show_worked'] = "Show worked";
$lang['awards_show_confirmed'] = "Show confirmed";
$lang['awards_show_not_worked'] = "Show not worked";
$lang['awards_show_cq_map'] = "Show CQ Zone Map";
$lang['awards_summary'] = "Summary";
$lang['awards_total'] = "Total";
$lang['awards_total_worked'] = "Total worked";
$lang['awards_total_confirmed'] = "Total confirmed";


$lang['awards_cq_page_title'] = "Awards - CQ Magazine WAZ";


/*
___________________________________________________________________________________________
CQ -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_cq_description_ln1'] = "CQ Magazine WAZ Award";
$lang['awards_cq_description_ln2'] = "The CQ Magazine is located in the US and one of the most popular amateur radio magazines in the world. The magazine first appeared in January 1945 and focuses on awards and the practical aspects of amateur radio.";
$lang['awards_cq_description_ln3'] = "The WAZ Award stands for 'Worked All Zones' and requires radio contacts to all 40 CQ Zones along with the corresponding confirmation.";
$lang['awards_cq_description_ln4'] = "You can find all the information and rules on the Website of the <a href='https://cq-amateur-radio.com/cq_awards/cq_waz_awards/index_cq_waz_award.html' target='_blank'>CQ Magazine</a>.";


/*
___________________________________________________________________________________________
DOK -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_dok_description_ln1'] = "DOK Award";
$lang['awards_dok_description_ln2'] = "Germany extends over 630 km from East to West and nearly 900 km from North to South. Around 70,000 of Germany's 82 million inhabitants are licensed hams, with more than 40,000 of them being members of DARC. DOK is a system that provides individual local chapters with an identifier and means 'Deutscher Ortsverband Kenner' (English: 'German Local Association Identifier').";
$lang['awards_dok_description_ln3'] = "The DOK consists of a letter for the district and a two-digit number for the local chapter, like P03 Friedrichshafen (city of the 'Hamradio exhibition') or F41 Baunatal (location of the DARC headquarters). Note: A zero in a DOK is a common mistake, often being logged as the letter O.";
$lang['awards_dok_description_ln4'] = "This information is provided by the <a href='https://www.darc.de/der-club/referate/conteste/wag-contest/en/service/districtsdoks/' target='_blank'>DARC website</a>. Information about the DOK Awards and its rules can be found <a href='https://www.darc.de/der-club/referate/conteste/wag-contest/en/service/award-check/' target='_blank'>here</a>.";


/*
___________________________________________________________________________________________
DXCC -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_dxcc_description_ln1'] = "DXCC Award";
$lang['awards_dxcc_description_ln2'] = "DXCC stands for 'DX Century Club,' an award based on worked countries. The DXCC List is based on an article created in 1935 by Clinton B. DeSoto, W1CBD, titled <a href='http://www.arrl.org/desoto' target='_blank'>'How to Count Countries Worked, A New DX Scoring System'</a>.";
$lang['awards_dxcc_description_ln3'] = "You can find all information about the DXCC Award on the <a href='https://www.arrl.org/dxcc-rules' target='_blank'>ARRL website</a>.";
$lang['awards_dxcc_description_ln4'] = "Important Note: Over time, the criteria for the DXCC List have changed. The List remains unchanged until an entity no longer satisfies the criteria under which it was added, at which time it is moved to the Deleted List. You will find Deleted DXCC entities also in the lists on Cloudlog. Be aware that these DXCC entities are outdated and no longer valid.";


/*
___________________________________________________________________________________________
FFMA -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_ffma_description_ln1'] = "Fred Fish Memorial Award";
$lang['awards_ffma_description_ln2'] = "The Fred Fish Memorial Award was created in honor of Fred Fish, W5FF (SK), who was the first amateur to have worked and confirmed all 488 Maidenhead grid squares in the 48 contiguous United States on 6 Meters.";
$lang['awards_ffma_description_ln3'] = "The award will be given to any amateur who can duplicate W5FF's accomplishment.";
$lang['awards_ffma_description_ln4'] = "For more information, you can visit this link: <a href='https://www.arrl.org/ffma' target='_blank'>https://www.arrl.org/ffma</a>.";


/*
___________________________________________________________________________________________
IOTA -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_iota_description_ln1'] = "IOTA Awards";
$lang['awards_iota_description_ln2'] = "IOTA is an exciting and innovative activity program that has captured the interest of thousands of radio amateurs worldwide. Established in 1964, it promotes radio contacts with stations located on islands around the world to enhance the experience of all those active on the amateur bands. To achieve this, it draws on the widespread mystique surrounding islands.";
$lang['awards_iota_description_ln3'] = "It is administered by Islands On The Air (IOTA) Ltd (referred to as IOTA Management) in partnership with the Radio Society of Great Britain (RSGB). IOTA Management has grouped the world's islands into approximately 1200 'IOTA groups,' each having varying numbers of 'counters,' which are qualifying islands. These listings are published in the IOTA Directory and on the IOTA website. The objective for the IOTA Island Chaser is to make radio contact with at least one counter in as many of these groups as possible. The program has a well-defined set of rules and encourages friendly competition among chasers by publishing participant performance in an Honor Roll and annual listings, as well as recognizing it with certificates and prestigious awards.";
$lang['awards_iota_description_ln4'] = "You can also find this information on the <a href='https://www.iota-world.org/' target='_blank'>IOTA WORLD website</a>.";


/*
___________________________________________________________________________________________
POTA -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_pota_description_ln1'] = "POTA Awards";
$lang['awards_pota_description_ln2'] = "Parks on the Air® (POTA) started in early 2017 when the ARRL's National Parks on the Air special event ended. A group of volunteers wanted to continue the fun beyond the one-year event, and thus, POTA was born.";
$lang['awards_pota_description_ln3'] = "POTA works similarly to SOTA, with Activators and Hunters. For the awards, there are several categories based on the number of parks, geographic areas, and more.";
$lang['awards_pota_description_ln4'] = "For more information about the available awards and categories, please visit the <a href='https://parksontheair.com/pota-awards/' target='_blank'>Parks on the Air® website</a>.";


/*
___________________________________________________________________________________________
SIG -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_sig_description_ln1'] = "SIG Information";
$lang['awards_sig_description_ln2'] = "The SIG or Signature Category provides the possibility to use any kind of 'Award Signature' for awards that are not implemented in Cloudlog.";
$lang['awards_sig_description_ln3'] = "The reason for this is that the common ADIF format provides only a few dedicated fields for certain awards. SIG still makes it possible to use and evaluate all other types of signature markers.";
$lang['awards_sig_description_ln4'] = "In the QSO processing, you will find two fields: 'SIG' contains the actual marker, which is also visible in the award evaluation, and 'SIG INFO,' which contains a description of the signature. Both fields are freely customizable.";


/*
___________________________________________________________________________________________
SOTA -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_sota_description_ln1'] = "SOTA Awards";
$lang['awards_sota_description_ln2'] = "SOTA (Summits On The Air) is an award scheme for radio amateurs that encourages portable operation in mountainous areas.";
$lang['awards_sota_description_ln3'] = "It is fully operational in nearly a hundred countries worldwide. Each country has its own Association that defines the recognized SOTA summits within that Association. Each summit earns the activators and chasers a score related to the height of the summit. Certificates are available for various scores, leading to the prestigious 'Mountain Goat' and 'Shack Sloth' trophies. An Honor Roll for Activators and Chasers is maintained in the SOTA online database.";
$lang['awards_sota_description_ln4'] = "For more information, please visit: <a href='https://www.sota.org.uk/' target='_blank'>https://www.sota.org.uk/</a>.";


/*
___________________________________________________________________________________________
US Counties -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_counties_description_ln1'] = "US County Award";
$lang['awards_counties_description_ln2'] = "The United States of America Counties Award (USA-CA), sponsored by CQ magazine, is issued for confirmed two-way radio contacts with specified numbers of U.S. counties under rules and conditions you can find <a href='https://cq-amateur-radio.com/cq_awards/cq_usa_ca_awards/cq_usa_ca_awards.html' target='_blank'>here</a>.";
$lang['awards_counties_description_ln3'] = "USA-CA is available to all licensed amateurs worldwide and is issued to individuals for all county contacts made, regardless of callsigns used, operating locations, or dates.";
$lang['awards_counties_description_ln4'] = "Special USA-CA awards are also available to SWLs on a heard basis.";


/*
___________________________________________________________________________________________
US Gridmaster -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_us_gridmaster_description_ln1'] = "US Gridmaster Award";
$lang['awards_us_gridmaster_description_ln2'] = "The GridMaster Award is the most prestigious AMSAT award, first introduced in 2014 by the Star Comm Group. It is available to all amateur radio operators worldwide who manage to work all 488 grid squares in the USA via satellite and can provide QSL confirmations for each contact.";
$lang['awards_us_gridmaster_description_ln3'] = "Official information from the <a href='https://www.amsat.org/gridmaster/' target='_blank'>website</a>: Two-way communication must be established via amateur satellite with each grid. There is no minimum signal report required. Contacts must be made from the same location or from locations no two of which are more than 200 kilometers apart. The applicant's attestation in the award application serves as affirmation of abidance by the distance rule. Individuals may apply for and be granted multiple GridMaster awards when achieved from another location, which is in a different 200-kilometer circle.";
$lang['awards_us_gridmaster_description_ln4'] = "This map shows only QSOs worked on SAT.";


/*
___________________________________________________________________________________________
JA Gridmaster -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_ja_gridmaster_description_ln1'] = "JA Gridmaster Award";
$lang['awards_ja_gridmaster_description_ln2'] = "Just as the US Gridmaster this Award is based on working all gridsquares of Japan.";
$lang['awards_ja_gridmaster_description_ln3'] = "Additional Information and the rules about this award are still pending.";
$lang['awards_ja_gridmaster_description_ln4'] = "";


/*
___________________________________________________________________________________________
VUCC -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_vucc_description_ln1'] = "VUCC - VHF/UHF Century Club Award";
$lang['awards_vucc_description_ln2'] = "The VHF/UHF Century Club Award is given for a minimum number of worked and confirmed gridsquares on a desired band.";
$lang['awards_vucc_description_ln3'] = "Official information and the rules can be found in this document: <a href='https://www.arrl.org/vucc' target='_blank'>Click here</a>.";
$lang['awards_vucc_description_ln4'] = "Only VHF/UHF bands are relevant.";


/*
___________________________________________________________________________________________
WAS -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_was_description_ln1'] = "WAS Award";
$lang['awards_was_description_ln2'] = "ARRL's most popular award is the Worked All States Award. Thousands upon thousands of awards have been issued to hams around the world. In ARRL's 101st year, they have redesigned the certificates and the program in hopes of streamlining and improving the award program.";
$lang['awards_was_description_ln3'] = "The WAS (Worked All States) Award is available to all amateurs worldwide who submit proof with written confirmation of contacts with each of the 50 states of the United States of America. Amateurs in the U.S. and its possessions must be members of ARRL to apply for a WAS. Applicants from outside the U.S. are exempt from this requirement.";
$lang['awards_was_description_ln4'] = "All information and rules for the ARRL WAS Award can be found <a href='https://www.arrl.org/was' target='_blank'>here</a>.";


/*
___________________________________________________________________________________________
WWFF -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_wwff_description_ln1'] = "WWFF - World Wide Flora and Fauna Award";
$lang['awards_wwff_description_ln2'] = "WWFF, World Wide Flora and Fauna in Amateur Radio, encourages licensed ham radio operators to leave their shacks and operate portable in Protected Flora & Fauna areas (PFF) worldwide.";
$lang['awards_wwff_description_ln3'] = "More than 26,000 Protected Flora & Fauna (PFF) areas worldwide are already registered in the WWFF Directory. Hunters and Activators can apply for colorful awards, both globally and nationally.";
$lang['awards_wwff_description_ln4'] = "For more information, please visit: <a href='https://wwff.co/awards/' target='_blank'>https://wwff.co/awards/</a>.";

/*
___________________________________________________________________________________________
WAJA -- Use all 4 Lines of Text
___________________________________________________________________________________________
*/

$lang['awards_waja_description_ln1'] = "WAJA - Worked All Japan prefectures Award";
$lang['awards_waja_description_ln2'] = "WAJA, Worked All Japan prefectures in Amateur Radio, encourages licensed ham radio operators to work all the prefectures in Japan.";
$lang['awards_waja_description_ln3'] = "May be claimed for having contacted (heard) and received a QSL card from an amateur station located in each of the 47 prefectures of Japan. A list of QSL cards should be arranged in order of WAJA (HAJA) reference number, however names of prefectures may be omitted.";
$lang['awards_waja_description_ln4'] = "For more information, please visit: <a href='https://www.jarl.org/English/4_Library/A-4-2_Awards/Award_Main.htm' target='_blank'>https://www.jarl.org/English/4_Library/A-4-2_Awards/Award_Main.htm</a>.";

/*
___________________________________________________________________________________________
WAB -- Use all 3 Lines of Text
___________________________________________________________________________________________
*/
$lang['awards_waja_description_ln1'] = "WAB - Worked All Britain Award";
$lang['awards_wab_description_ln2'] = "The Amateur Radio Worked All Britain (WAB) Award is a prestigious recognition program within the amateur radio community that celebrates communication achievements across the United Kingdom. The WAB Award scheme encourages radio operators to establish contact with stations located in different regions of Britain, fostering camaraderie and promoting radio communication skills. To earn the WAB Award, participants must make successful radio contacts with stations located in specific WAB areas, which are defined by Ordnance Survey grid squares. These grid squares cover the entirety of Great Britain, including England, Scotland, Wales, and some offshore islands.";
$lang['awards_wab_description_ln3'] = "Participants in the WAB Award program exchange information such as their location, signal strength, and WAB square reference during radio contacts. Points are awarded based on the location of the contacted station, with different point values assigned to contacts made within different WAB areas. By accumulating points from successful contacts, radio operators can progress through various award levels, each representing a significant milestone in their amateur radio journey. The WAB Award not only recognizes the dedication and skill of radio operators but also promotes geographic diversity and encourages exploration of the rich tapestry of locations across Britain through the medium of amateur radio.";
$lang['awards_waja_description_ln4'] = "For more information, please visit: <a href='https://wab.intermip.net/default.php' target='_blank'>https://wab.intermip.net/default.php</a>.";
